Package: bayesmeta
Type: Package
Title: Bayesian Random-Effects Meta-Analysis and Meta-Regression
Version: 3.5
Date: 2025-08-29
Authors@R: c(person(given="Christian", family="Roever", role=c("aut","cre"), 
                    email="christian.roever@med.uni-goettingen.de",
                    comment=c(ORCID="0000-0002-6911-698X")),
             person(given="Tim", family="Friede", role="ctb",
                    email="tim.friede@med.uni-goettingen.de",
                    comment=c(ORCID="0000-0001-5347-7441")))
Maintainer: Christian Roever <christian.roever@med.uni-goettingen.de>
Depends: forestplot (>= 2.0.0), metafor (>= 2.0-0), mvtnorm (>= 1.1-1),
        numDeriv (>= 2016.8-1.1)
Suggests: compute.es, knitr, rmarkdown, R.rsp
Description: A collection of functions allowing to derive the posterior distribution of the model parameters in random-effects meta-analysis or meta-regression, and providing functionality to evaluate joint and marginal posterior probability distributions, predictive distributions, shrinkage effects, posterior predictive p-values, etc.; For more details, see also Roever C (2020) <doi:10.18637/jss.v093.i06>, or Roever C and Friede T (2022) <doi:10.1016/j.cmpb.2022.107303>.
License: GPL (>= 2)
URL: https://gitlab.gwdg.de/croever/bayesmeta
VignetteBuilder: knitr, R.rsp
NeedsCompilation: no
Packaged: 2025-08-29 05:24:15 UTC; christian
Author: Christian Roever [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6911-698X>),
  Tim Friede [ctb] (ORCID: <https://orcid.org/0000-0001-5347-7441>)
Repository: CRAN
Date/Publication: 2025-08-29 06:20:09 UTC
Built: R 4.6.0; ; 2026-04-27 07:10:13 UTC; unix
