export(bayesmeta, bmr,
       print.bayesmeta, summary.bayesmeta, plot.bayesmeta,
       print.bmr, summary.bmr, print.summary.bmr,
       plot.bmr, pairs.bmr,
       forestplot.bayesmeta, forestplot.escalc, forestplot.bmr,
       dlomax, plomax, qlomax, rlomax, elomax, vlomax,
       dhalfnormal, phalfnormal, qhalfnormal, rhalfnormal,
         ehalfnormal, vhalfnormal,
       dhalft, phalft, qhalft, rhalft, ehalft, vhalft,
       dhalfcauchy, phalfcauchy, qhalfcauchy, rhalfcauchy,
         ehalfcauchy, vhalfcauchy,
       dhalflogistic, phalflogistic, qhalflogistic, rhalflogistic,
         ehalflogistic, vhalflogistic,
       dinvchi, pinvchi, qinvchi, rinvchi, einvchi, vinvchi,
       drayleigh, prayleigh, qrayleigh, rrayleigh, erayleigh, vrayleigh,
       TurnerEtAlParameters, TurnerEtAlPrior,
       RhodesEtAlParameters, RhodesEtAlPrior,
       convolve, funnel.bayesmeta,
       normalmixture, pppvalue, uisd, ess, weightsplot, traceplot,
       kldiv)

S3method(bayesmeta, default)
S3method(bayesmeta, escalc)
S3method(print, bayesmeta)
S3method(summary, bayesmeta)
S3method(plot, bayesmeta)
S3method(forestplot, bayesmeta)
S3method(forestplot, escalc)
S3method(forest, bayesmeta)
S3method(funnel, bayesmeta)
S3method(uisd, default)
S3method(uisd, escalc)
S3method(ess, bayesmeta)
S3method(weightsplot, bayesmeta)
S3method(traceplot, bayesmeta)
S3method(bmr, default)
S3method(bmr, escalc)
S3method(print, bmr)
S3method(summary, bmr)
S3method(print, summary.bmr)
S3method(plot, bmr)
S3method(pairs, bmr)
S3method(forestplot, bmr)
S3method(traceplot, bmr)

importFrom("grDevices",
           "grey", "rainbow", "rgb")
importFrom("graphics",
           "abline", "axis", "barplot", "box", "contour", "image", "layout",
           "lines", "matlines", "mtext", "par", "plot", "points", "polygon",
           "text")
importFrom("stats",
           "dcauchy", "dlnorm", "dlogis", "dnorm", "dt", "integrate", "lm.fit",
           "median", "optim", "optimize", "pcauchy", "plnorm", "plogis",
           "pnorm", "pt", "qcauchy", "qchisq", "qlnorm", "qlogis", "qnorm",
           "qt", "rcauchy", "rexp", "rlogis", "rmultinom", "rnorm", "rt",
           "runif", "uniroot")
importFrom("forestplot",
           "forestplot", "fpDrawPointCI", "fpDrawSummaryCI","fpDrawBarCI",
           "fpColors")
importFrom("metafor",
           "forest", "funnel")
importFrom("mvtnorm",
           "dmvnorm", "rmvnorm")
importFrom("numDeriv",
           "hessian")
importFrom("parallel",
           "detectCores", "makeCluster", "clusterEvalQ","parSapply",
           "stopCluster")
importFrom("utils",
           "txtProgressBar", "setTxtProgressBar")
